@@ -20,15 +20,28 @@ class Event(Enum):
 
     Attributes:
         STARTED: Emitted once at the start of a run.
-        EPOCH_STARTED: Emitted at the start of each epoch.
-        BATCH_STARTED: Emitted at the start of each batch.
-        BATCH_FINISHED: Emitted every time a batch is finished.
-        EPOCH_FINISHED: Emitted every time an epoch is finished.
-        FINISHED: Emitted once when a run is finished.
+        EPOCH_STARTED: Emitted at the start of every epoch.
+        BATCH: Emitted on every batch.
+        EPOCH_FINISHED: Emitted at the end of every epoch.
+        FINISHED: Emitted once at the end of a run.
     """
+
     STARTED = auto()
     EPOCH_STARTED = auto()
-    BATCH_STARTED = auto()
-    BATCH_FINISHED = auto()
+    BATCH = auto()
     EPOCH_FINISHED = auto()
     FINISHED = auto()
+
+    # Events for EpochTimer attachment
+    _ETIMER_STARTED = auto()
+    _ETIMER_FINISHED = auto()
+
+    # Events for ProgressBar attachment
+    _PBAR_CREATED = auto()
+    _PBAR_UPDATED = auto()
+    _PBAR_CLOSED = auto()
+
+    # Events for LambdaReducer attachment
+    _REDUCER_RESET = auto()
+    _REDUCER_UPDATED = auto()
+    _REDUCER_COMPUTED = auto()
